@@ -7,7 +7,7 @@
 #  define VTKFILTERSPARALLELIMAGING_NO_EXPORT
 #else
 #  ifndef VTKFILTERSPARALLELIMAGING_EXPORT
-#    ifdef vtkFiltersParallelImaging_EXPORTS
+#    ifdef FiltersParallelImaging_EXPORTS
         /* We are building this library */
 #      define VTKFILTERSPARALLELIMAGING_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,16 +23,20 @@
 
 #ifndef VTKFILTERSPARALLELIMAGING_DEPRECATED
 #  define VTKFILTERSPARALLELIMAGING_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKFILTERSPARALLELIMAGING_DEPRECATED_EXPORT VTKFILTERSPARALLELIMAGING_EXPORT __attribute__ ((__deprecated__))
-#  define VTKFILTERSPARALLELIMAGING_DEPRECATED_NO_EXPORT VTKFILTERSPARALLELIMAGING_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKFILTERSPARALLELIMAGING_NO_DEPRECATED
+#ifndef VTKFILTERSPARALLELIMAGING_DEPRECATED_EXPORT
+#  define VTKFILTERSPARALLELIMAGING_DEPRECATED_EXPORT VTKFILTERSPARALLELIMAGING_EXPORT VTKFILTERSPARALLELIMAGING_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkFiltersParallelModule.h"
-
+#ifndef VTKFILTERSPARALLELIMAGING_DEPRECATED_NO_EXPORT
+#  define VTKFILTERSPARALLELIMAGING_DEPRECATED_NO_EXPORT VTKFILTERSPARALLELIMAGING_NO_EXPORT VTKFILTERSPARALLELIMAGING_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKFILTERSPARALLELIMAGING_NO_DEPRECATED
+#    define VTKFILTERSPARALLELIMAGING_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKFILTERSPARALLELIMAGING_EXPORT_H */
