@@ -7,7 +7,7 @@
 #  define VTKRENDERINGANNOTATION_NO_EXPORT
 #else
 #  ifndef VTKRENDERINGANNOTATION_EXPORT
-#    ifdef vtkRenderingAnnotation_EXPORTS
+#    ifdef RenderingAnnotation_EXPORTS
         /* We are building this library */
 #      define VTKRENDERINGANNOTATION_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,16 +23,20 @@
 
 #ifndef VTKRENDERINGANNOTATION_DEPRECATED
 #  define VTKRENDERINGANNOTATION_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKRENDERINGANNOTATION_DEPRECATED_EXPORT VTKRENDERINGANNOTATION_EXPORT __attribute__ ((__deprecated__))
-#  define VTKRENDERINGANNOTATION_DEPRECATED_NO_EXPORT VTKRENDERINGANNOTATION_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKRENDERINGANNOTATION_NO_DEPRECATED
+#ifndef VTKRENDERINGANNOTATION_DEPRECATED_EXPORT
+#  define VTKRENDERINGANNOTATION_DEPRECATED_EXPORT VTKRENDERINGANNOTATION_EXPORT VTKRENDERINGANNOTATION_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkRenderingCoreModule.h"
-
+#ifndef VTKRENDERINGANNOTATION_DEPRECATED_NO_EXPORT
+#  define VTKRENDERINGANNOTATION_DEPRECATED_NO_EXPORT VTKRENDERINGANNOTATION_NO_EXPORT VTKRENDERINGANNOTATION_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKRENDERINGANNOTATION_NO_DEPRECATED
+#    define VTKRENDERINGANNOTATION_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKRENDERINGANNOTATION_EXPORT_H */
