@@ -7,7 +7,7 @@
 #  define VTKTESTINGIOSQL_NO_EXPORT
 #else
 #  ifndef VTKTESTINGIOSQL_EXPORT
-#    ifdef vtkTestingIOSQL_EXPORTS
+#    ifdef TestingIOSQL_EXPORTS
         /* We are building this library */
 #      define VTKTESTINGIOSQL_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,15 +23,20 @@
 
 #ifndef VTKTESTINGIOSQL_DEPRECATED
 #  define VTKTESTINGIOSQL_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKTESTINGIOSQL_DEPRECATED_EXPORT VTKTESTINGIOSQL_EXPORT __attribute__ ((__deprecated__))
-#  define VTKTESTINGIOSQL_DEPRECATED_NO_EXPORT VTKTESTINGIOSQL_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKTESTINGIOSQL_NO_DEPRECATED
+#ifndef VTKTESTINGIOSQL_DEPRECATED_EXPORT
+#  define VTKTESTINGIOSQL_DEPRECATED_EXPORT VTKTESTINGIOSQL_EXPORT VTKTESTINGIOSQL_DEPRECATED
 #endif
 
-
-
+#ifndef VTKTESTINGIOSQL_DEPRECATED_NO_EXPORT
+#  define VTKTESTINGIOSQL_DEPRECATED_NO_EXPORT VTKTESTINGIOSQL_NO_EXPORT VTKTESTINGIOSQL_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKTESTINGIOSQL_NO_DEPRECATED
+#    define VTKTESTINGIOSQL_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKTESTINGIOSQL_EXPORT_H */
